@@ -2,8 +2,8 @@ package Class::MOP::Mixin;
 BEGIN {
   $Class::MOP::Mixin::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Class::MOP::Mixin::VERSION = '2.0200';
+{
+  $Class::MOP::Mixin::VERSION = '2.1005';
 }
 
 use strict;
@@ -20,7 +20,7 @@ sub meta {
 
 # ABSTRACT: Base class for mixin classes
 
-
+__END__
 
 =pod
 
@@ -30,7 +30,7 @@ Class::MOP::Mixin - Base class for mixin classes
 
 =head1 VERSION
 
-version 2.0200
+version 2.1005
 
 =head1 DESCRIPTION
 
@@ -50,17 +50,13 @@ This returns a L<Class::MOP::Class> object for the mixin class.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
