@@ -2,8 +2,8 @@ package Class::MOP::Mixin::AttributeCore;
 BEGIN {
   $Class::MOP::Mixin::AttributeCore::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Class::MOP::Mixin::AttributeCore::VERSION = '2.0200';
+{
+  $Class::MOP::Mixin::AttributeCore::VERSION = '2.1005';
 }
 
 use strict;
@@ -55,7 +55,7 @@ sub default {
 
 # ABSTRACT: Core attributes shared by attribute metaclasses
 
-
+__END__
 
 =pod
 
@@ -65,7 +65,7 @@ Class::MOP::Mixin::AttributeCore - Core attributes shared by attribute metaclass
 
 =head1 VERSION
 
-version 2.0200
+version 2.1005
 
 =head1 DESCRIPTION
 
@@ -74,17 +74,13 @@ attributes. See the L<Class::MOP::Attribute> documentation for API details.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
