@@ -3,18 +3,21 @@ BEGIN {
   $Class::MOP::Mixin::HasMethods::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Class::MOP::Mixin::HasMethods::VERSION = '2.0402';
+  $Class::MOP::Mixin::HasMethods::VERSION = '2.1005';
 }
 
 use strict;
 use warnings;
 
 use Class::MOP::Method::Meta;
+use Class::MOP::Method::Overload;
 
-use Scalar::Util 'blessed';
+use Scalar::Util 'blessed', 'reftype';
 use Carp         'confess';
 use Sub::Name    'subname';
 
+use overload ();
+
 use base 'Class::MOP::Mixin';
 
 sub _meta_method_class { 'Class::MOP::Method::Meta' }
@@ -39,7 +42,7 @@ sub _add_meta_method {
 sub wrap_method_body {
     my ( $self, %args ) = @_;
 
-    ( 'CODE' eq ref $args{body} )
+    ( 'CODE' eq reftype $args{body} )
         || confess "Your code block must be a CODE reference";
 
     $self->method_metaclass->wrap(
@@ -56,7 +59,7 @@ sub add_method {
     my $package_name = $self->name;
 
     my $body;
-    if ( blessed($method) ) {
+    if ( blessed($method) && $method->isa('Class::MOP::Method') ) {
         $body = $method->body;
         if ( $method->package_name ne $package_name ) {
             $method = $method->clone(
@@ -116,7 +119,7 @@ sub get_method {
     my $method = $self->_get_maybe_raw_method($method_name)
         or return;
 
-    return $method if blessed $method;
+    return $method if blessed($method) && $method->isa('Class::MOP::Method');
 
     return $self->_method_map->{$method_name} = $self->wrap_method_body(
         body                 => $method,
@@ -149,7 +152,7 @@ sub remove_method {
     $self->remove_package_symbol("&$method_name");
 
     $removed_method->detach_from_class
-        if blessed($removed_method);
+        if blessed($removed_method) && $removed_method->isa('Class::MOP::Method');
 
     # still valid, since we just removed the method from the map
     $self->update_package_cache_flag;
@@ -206,11 +209,102 @@ sub _full_method_map {
     return $self->_method_map;
 }
 
+# overloading
+
+my $overload_operators;
+sub overload_operators {
+    $overload_operators ||= [map { split /\s+/ } values %overload::ops];
+    return @$overload_operators;
+}
+
+sub is_overloaded {
+    my $self = shift;
+    return overload::Overloaded($self->name);
+}
+
+# XXX this could probably stand to be cached, but i figure it should be
+# uncommon enough to not particularly matter
+sub _overload_map {
+    my $self = shift;
+
+    return {} unless $self->is_overloaded;
+
+    my %map;
+    for my $op ($self->overload_operators) {
+        my $body = $self->_get_overloaded_operator_body($op);
+        next unless defined $body;
+        $map{$op} = $body;
+    }
+
+    return \%map;
+}
+
+sub get_overload_list {
+    my $self = shift;
+    return keys %{ $self->_overload_map };
+}
+
+sub get_all_overloaded_operators {
+    my $self = shift;
+    my $map = $self->_overload_map;
+    return map { $self->_wrap_overload($_, $map->{$_}) } keys %$map;
+}
+
+sub has_overloaded_operator {
+    my $self = shift;
+    my ($op) = @_;
+    return defined $self->_get_overloaded_operator_body($op);
+}
+
+sub get_overloaded_operator {
+    my $self = shift;
+    my ($op) = @_;
+    my $body = $self->_get_overloaded_operator_body($op);
+    return unless defined $body;
+    return $self->_wrap_overload($op, $body);
+}
+
+sub add_overloaded_operator {
+    my $self = shift;
+    my ($op, $body) = @_;
+    $self->name->overload::OVERLOAD($op => $body);
+}
+
+sub remove_overloaded_operator {
+    my $self = shift;
+    my ($op) = @_;
+
+    if ( $] < 5.018 ) {
+        # ugh, overload.pm provides no api for this - but the problem that
+        # makes this necessary has been fixed in 5.18
+        $self->get_or_add_package_symbol('%OVERLOAD')->{dummy}++;
+    }
+
+    $self->remove_package_symbol('&(' . $op);
+}
+
+sub _get_overloaded_operator_body {
+    my $self = shift;
+    my ($op) = @_;
+    return overload::Method($self->name, $op);
+}
+
+sub _wrap_overload {
+    my $self = shift;
+    my ($op, $body) = @_;
+    return Class::MOP::Method::Overload->wrap(
+        operator             => $op,
+        package_name         => $self->name,
+        associated_metaclass => $self,
+        body                 => $body,
+    );
+}
+
 1;
 
 # ABSTRACT: Methods for metaclasses which have methods
 
-
+__END__
 
 =pod
 
@@ -220,7 +314,7 @@ Class::MOP::Mixin::HasMethods - Methods for metaclasses which have methods
 
 =head1 VERSION
 
-version 2.0402
+version 2.1005
 
 =head1 DESCRIPTION
 
@@ -234,13 +328,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
