@@ -2,8 +2,8 @@ package Moose::Error::Confess;
 BEGIN {
   $Moose::Error::Confess::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Error::Confess::VERSION = '2.0200';
+{
+  $Moose::Error::Confess::VERSION = '2.1005';
 }
 
 use strict;
@@ -30,7 +30,7 @@ sub _inline_new {
 
 # ABSTRACT: Prefer C<confess>
 
-
+__END__
 
 =pod
 
@@ -40,7 +40,7 @@ Moose::Error::Confess - Prefer C<confess>
 
 =head1 VERSION
 
-version 2.0200
+version 2.1005
 
 =head1 SYNOPSIS
 
@@ -59,20 +59,13 @@ metaclass.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
-
-
