@@ -4,12 +4,11 @@ BEGIN {
   $Moose::Meta::Attribute::Native::Trait::Counter::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Attribute::Native::Trait::Counter::VERSION = '2.0401';
+  $Moose::Meta::Attribute::Native::Trait::Counter::VERSION = '2.1005';
 }
 use Moose::Role;
 
-with 'Moose::Meta::Attribute::Native::Trait' =>
-    { -excludes => ['_root_types'] };
+with 'Moose::Meta::Attribute::Native::Trait';
 
 sub _default_default { 0 }
 sub _default_is { 'ro' }
@@ -22,7 +21,7 @@ no Moose::Role;
 
 # ABSTRACT: Helper trait for Int attributes which represent counters
 
-
+__END__
 
 =pod
 
@@ -32,7 +31,7 @@ Moose::Meta::Attribute::Native::Trait::Counter - Helper trait for Int attributes
 
 =head1 VERSION
 
-version 2.0401
+version 2.1005
 
 =head1 SYNOPSIS
 
@@ -114,13 +113,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
