@@ -2,8 +2,8 @@ package Moose::Meta::Method::Accessor::Native::Array::map;
 BEGIN {
   $Moose::Meta::Method::Accessor::Native::Array::map::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::map::VERSION = '2.0200';
+{
+  $Moose::Meta::Method::Accessor::Native::Array::map::VERSION = '2.1005';
 }
 
 use strict;
@@ -13,15 +13,7 @@ use Params::Util ();
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            _inline_check_arguments
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _minimum_arguments { 1 }
 
