@@ -2,8 +2,8 @@ package Moose::Meta::Method::Accessor::Native::Array::pop;
 BEGIN {
   $Moose::Meta::Method::Accessor::Native::Array::pop::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::pop::VERSION = '2.0200';
+{
+  $Moose::Meta::Method::Accessor::Native::Array::pop::VERSION = '2.1005';
 }
 
 use strict;
@@ -11,14 +11,7 @@ use warnings;
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Array::Writer' => {
-    -excludes => [
-        qw( _maximum_arguments
-            _inline_capture_return_value
-            _inline_optimized_set_new_value
-            _return_value )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Array::Writer';
 
 sub _maximum_arguments { 0 }
 
