@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Counter::inc::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Counter::inc::VERSION = '2.0402';
+  $Moose::Meta::Method::Accessor::Native::Counter::inc::VERSION = '2.1005';
 }
 
 use strict;
@@ -11,15 +11,7 @@ use warnings;
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Writer' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            _inline_optimized_set_new_value
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Writer';
 
 sub _minimum_arguments { 0 }
 sub _maximum_arguments { 1 }
