@@ -2,8 +2,8 @@ package Moose::Meta::Method::Accessor::Native::Counter::reset;
 BEGIN {
   $Moose::Meta::Method::Accessor::Native::Counter::reset::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Counter::reset::VERSION = '2.0200';
+{
+  $Moose::Meta::Method::Accessor::Native::Counter::reset::VERSION = '2.1005';
 }
 
 use strict;
@@ -11,14 +11,7 @@ use warnings;
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Writer' => {
-    -excludes => [
-        qw(
-            _maximum_arguments
-            _inline_optimized_set_new_value
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Writer';
 
 sub _maximum_arguments { 0 }
 
