@@ -2,8 +2,8 @@ package Moose::Meta::Method::Accessor::Native::Hash::defined;
 BEGIN {
   $Moose::Meta::Method::Accessor::Native::Hash::defined::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Hash::defined::VERSION = '2.0200';
+{
+  $Moose::Meta::Method::Accessor::Native::Hash::defined::VERSION = '2.1005';
 }
 
 use strict;
@@ -13,16 +13,8 @@ use Scalar::Util qw( looks_like_number );
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            _inline_check_arguments
-            )
-    ],
-    },
-    'Moose::Meta::Method::Accessor::Native::Hash';
+with 'Moose::Meta::Method::Accessor::Native::Reader',
+     'Moose::Meta::Method::Accessor::Native::Hash';
 
 sub _minimum_arguments { 1 }
 
