@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Method::Accessor::Native::Hash::shallow_clone::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Method::Accessor::Native::Hash::shallow_clone::VERSION = '2.0401';
+  $Moose::Meta::Method::Accessor::Native::Hash::shallow_clone::VERSION = '2.1005';
 }
 
 use strict;
@@ -13,14 +13,7 @@ use Params::Util ();
 
 use Moose::Role;
 
-with 'Moose::Meta::Method::Accessor::Native::Reader' => {
-    -excludes => [
-        qw(
-            _minimum_arguments
-            _maximum_arguments
-            )
-    ]
-};
+with 'Moose::Meta::Method::Accessor::Native::Reader';
 
 sub _minimum_arguments { 0 }
 
