@@ -1,12 +1,14 @@
 package Moose::Meta::Method::Augmented;
+BEGIN {
+  $Moose::Meta::Method::Augmented::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Method::Augmented::VERSION = '2.1005';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '1.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Method';
 
 sub new {
@@ -56,6 +58,8 @@ sub new {
 
 1;
 
+# ABSTRACT: A Moose Method metaclass for augmented methods
+
 __END__
 
 =pod
@@ -64,6 +68,10 @@ __END__
 
 Moose::Meta::Method::Augmented - A Moose Method metaclass for augmented methods
 
+=head1 VERSION
+
+version 2.1005
+
 =head1 DESCRIPTION
 
 This class implements method augmentation logic for the L<Moose>
@@ -111,15 +119,13 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@cpan.orgE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
