@@ -1,4 +1,10 @@
 package Moose::Meta::Role::Application::ToRole;
+BEGIN {
+  $Moose::Meta::Role::Application::ToRole::AUTHORITY = 'cpan:STEVAN';
+}
+{
+  $Moose::Meta::Role::Application::ToRole::VERSION = '2.1005';
+}
 
 use strict;
 use warnings;
@@ -6,10 +12,6 @@ use metaclass;
 
 use Scalar::Util    'blessed';
 
-our $VERSION   = '0.82';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
-
 use base 'Moose::Meta::Role::Application';
 
 sub apply {
@@ -27,7 +29,7 @@ sub check_role_exclusions {
     foreach my $excluded_role_name ($role1->get_excluded_roles_list) {
         if ( $role2->does_role($excluded_role_name) ) {
             require Moose;
-            Moose->throw_error("The class " . $role2->name . " does the excluded role '$excluded_role_name'");
+            Moose->throw_error("The role " . $role2->name . " does the excluded role '$excluded_role_name'");
         }
         $role2->add_excluded_roles($excluded_role_name);
     }
@@ -57,69 +59,74 @@ sub apply_attributes {
             # make sure we haven't seen this one already too
             $role2->get_attribute($attribute_name) != $role1->get_attribute($attribute_name)) {
 
+            my $role2_name = $role2->name;
+
             require Moose;
-            Moose->throw_error("Role '" . $role1->name . "' has encountered an attribute conflict " .
-                    "during composition. This is fatal error and cannot be disambiguated.");
+            Moose->throw_error( "Role '"
+                    . $role1->name
+                    . "' has encountered an attribute conflict"
+                    . " while being composed into '$role2_name'."
+                    . " This is a fatal error and cannot be disambiguated."
+                    . " The conflicting attribute is named '$attribute_name'." );
         }
         else {
             $role2->add_attribute(
-                $attribute_name,
-                $role1->get_attribute($attribute_name)
+                $role1->get_attribute($attribute_name)->clone
             );
         }
     }
 }
 
 sub apply_methods {
-    my ($self, $role1, $role2) = @_;
-    foreach my $method_name ($role1->get_method_list) {
+    my ( $self, $role1, $role2 ) = @_;
+    foreach my $method ( $role1->_get_local_methods ) {
 
-        if ($self->is_method_aliased($method_name)) {
-            my $aliased_method_name = $self->get_method_aliases->{$method_name};
-            # it if it has one already
-            if ($role2->has_method($aliased_method_name) &&
-                # and if they are not the same thing ...
-                $role2->get_method($aliased_method_name)->body != $role1->get_method($method_name)->body) {
+        my $method_name = $method->name;
 
-                require Moose;
-                Moose->throw_error("Cannot create a method alias if a local method of the same name exists");
+        next if $method->isa('Class::MOP::Method::Meta');
+
+        unless ( $self->is_method_excluded($method_name) ) {
+
+            my $role2_method = $role2->get_method($method_name);
+            if (   $role2_method
+                && $role2_method->body != $method->body ) {
+
+                # method conflicts between roles used to result in the method
+                # becoming a requirement but now are permitted just like
+                # for classes, hence no code in this branch anymore.
             }
-
-            $role2->add_method(
-                $aliased_method_name,
-                $role1->get_method($method_name)
-            );
-
-            if (!$role2->has_method($method_name)) {
-                $role2->add_required_methods($method_name)
-                    unless $self->is_method_excluded($method_name);
+            else {
+                $role2->add_method(
+                    $method_name,
+                    $method,
+                );
             }
-
-            next;
         }
 
-        next if $self->is_method_excluded($method_name);
+        next unless $self->is_method_aliased($method_name);
 
-        # it if it has one already
-        if ($role2->has_method($method_name) &&
-            # and if they are not the same thing ...
-            $role2->get_method($method_name)->body != $role1->get_method($method_name)->body) {
-            # method conflicts between roles result
-            # in the method becoming a requirement
-            $role2->add_conflicting_method(
-                name  => $method_name,
-                roles => [$role1->name, $role2->name],
+        my $aliased_method_name = $self->get_method_aliases->{$method_name};
+
+        my $role2_method = $role2->get_method($aliased_method_name);
+
+        if (   $role2_method
+            && $role2_method->body != $method->body ) {
+
+            require Moose;
+            Moose->throw_error(
+                "Cannot create a method alias if a local method of the same name exists"
             );
         }
-        else {
-            # add it, although it could be overridden
-            $role2->add_method(
-                $method_name,
-                $role1->get_method($method_name)
-            );
 
+        $role2->add_method(
+            $aliased_method_name,
+            $role1->get_method($method_name)
+        );
+
+        if ( !$role2->has_method($method_name) ) {
+            $role2->add_required_methods($method_name)
+                unless $self->is_method_excluded($method_name);
         }
-
     }
 }
 
@@ -139,7 +146,7 @@ sub apply_override_method_modifiers {
         }
         else {
             # if we are a role, we need to make sure
-            # we dont have a conflict with the role
+            # we don't have a conflict with the role
             # we are composing into
             if ($role2->has_override_method_modifier($method_name) &&
                 $role2->get_override_method_modifier($method_name) != $role2->get_override_method_modifier($method_name)) {
@@ -176,6 +183,8 @@ sub apply_method_modifiers {
 
 1;
 
+# ABSTRACT: Compose a role into another role
+
 __END__
 
 =pod
@@ -184,6 +193,10 @@ __END__
 
 Moose::Meta::Role::Application::ToRole - Compose a role into another role
 
+=head1 VERSION
+
+version 2.1005
+
 =head1 DESCRIPTION
 
 =head2 METHODS
@@ -214,22 +227,17 @@ Moose::Meta::Role::Application::ToRole - Compose a role into another role
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
