@@ -3,7 +3,7 @@ BEGIN {
   $Moose::Meta::Role::Attribute::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Meta::Role::Attribute::VERSION = '2.0401';
+  $Moose::Meta::Role::Attribute::VERSION = '2.1005';
 }
 
 use strict;
@@ -129,7 +129,7 @@ sub is_same_as {
 
 # ABSTRACT: The Moose attribute metaclass for Roles
 
-
+__END__
 
 =pod
 
@@ -139,7 +139,7 @@ Moose::Meta::Role::Attribute - The Moose attribute metaclass for Roles
 
 =head1 VERSION
 
-version 2.0401
+version 2.1005
 
 =head1 DESCRIPTION
 
@@ -171,8 +171,8 @@ Returns the L<Moose::Meta::Role> to which this attribute belongs, if any.
 =item B<< $attr->original_role >>
 
 Returns the L<Moose::Meta::Role> in which this attribute was first
-defined. This may not be the same as the value C<associated_role()> in the
-case of composite role, or the case where one role consumes other roles.
+defined. This may not be the same as the value of C<associated_role()> for
+attributes in a composite role, or when one role consumes other roles.
 
 =item B<< $attr->original_options >>
 
@@ -212,13 +212,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
