@@ -3,13 +3,13 @@ BEGIN {
   $Moose::Util::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Moose::Util::VERSION = '2.0401';
+  $Moose::Util::VERSION = '2.1005';
 }
 
 use strict;
 use warnings;
 
-use Class::Load qw(load_class load_first_existing_class);
+use Class::Load 0.07 qw(load_class load_first_existing_class);
 use Data::OptList;
 use Params::Util qw( _STRING );
 use Sub::Exporter;
@@ -285,7 +285,7 @@ sub _caller_info {
     my $level = @_ ? ($_[0] + 1) : 2;
     my %info;
     @info{qw(package file line)} = caller($level);
-    return \%info;
+    return %info;
 }
 
 sub _create_alias {
@@ -314,12 +314,14 @@ sub meta_class_alias {
 
 # XXX - this should be added to Params::Util
 sub _STRINGLIKE0 ($) {
-    return _STRING( $_[0] )
-        || ( defined $_[0]
-        && $_[0] eq q{} )
-        || ( blessed $_[0]
-        && overload::Method( $_[0], q{""} )
-        && length "$_[0]" );
+    return 1 if _STRING( $_[0] );
+    if ( blessed $_[0] ) {
+        return overload::Method( $_[0], q{""} );
+    }
+
+    return 1 if defined $_[0] && $_[0] eq q{};
+
+    return 0;
 }
 
 sub _reconcile_roles_for_metaclass {
@@ -345,20 +347,24 @@ sub _reconcile_roles_for_metaclass {
 
 sub _role_differences {
     my ($class_meta_name, $super_meta_name) = @_;
-    my @super_role_metas
-        = grep { !$_->isa('Moose::Meta::Role::Composite') }
-               $super_meta_name->meta->can('calculate_all_roles_with_inheritance')
-                   ? $super_meta_name->meta->calculate_all_roles_with_inheritance
-                   : $super_meta_name->meta->can('calculate_all_roles')
-                   ? $super_meta_name->meta->calculate_all_roles
-                   : ();
-    my @role_metas
-        = grep { !$_->isa('Moose::Meta::Role::Composite') }
-               $class_meta_name->meta->can('calculate_all_roles_with_inheritance')
-                   ? $class_meta_name->meta->calculate_all_roles_with_inheritance
-                   : $class_meta_name->meta->can('calculate_all_roles')
-                   ? $class_meta_name->meta->calculate_all_roles
-                   : ();
+    my @super_role_metas = map {
+        $_->isa('Moose::Meta::Role::Composite')
+            ? (@{ $_->get_roles })
+            : ($_)
+    } $super_meta_name->meta->can('_roles_with_inheritance')
+        ? $super_meta_name->meta->_roles_with_inheritance
+    : $super_meta_name->meta->can('roles')
+        ? @{ $super_meta_name->meta->roles }
+    :     ();
+    my @role_metas = map {
+        $_->isa('Moose::Meta::Role::Composite')
+            ? (@{ $_->get_roles })
+            : ($_)
+    } $class_meta_name->meta->can('_roles_with_inheritance')
+        ? $class_meta_name->meta->_roles_with_inheritance
+    : $class_meta_name->meta->can('roles')
+        ? @{ $class_meta_name->meta->roles }
+    :     ();
     my @differences;
     for my $role_meta (@role_metas) {
         push @differences, $role_meta
@@ -478,7 +484,7 @@ sub _is_role_only_subclass {
 
 # ABSTRACT: Utilities for working with Moose classes
 
-
+__END__
 
 =pod
 
@@ -488,7 +494,7 @@ Moose::Util - Utilities for working with Moose classes
 
 =head1 VERSION
 
-version 2.0401
+version 2.1005
 
 =head1 SYNOPSIS
 
@@ -548,7 +554,7 @@ each of which can be followed by an optional hash reference of options
 
 =item B<ensure_all_roles($applicant, @roles)>
 
-This function is similar to L</apply_all_roles>, but only applies roles that
+This function is similar to C<apply_all_roles>, but only applies roles that
 C<$applicant> does not already consume.
 
 =item B<with_traits($class_name, @role_names)>
@@ -622,14 +628,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
