@@ -2,8 +2,8 @@ package Moose::Util::MetaRole;
 BEGIN {
   $Moose::Util::MetaRole::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Util::MetaRole::VERSION = '2.0200';
+{
+  $Moose::Util::MetaRole::VERSION = '2.1005';
 }
 
 use strict;
@@ -142,7 +142,7 @@ sub _make_new_class {
 
 # ABSTRACT: Apply roles to any metaclass, as well as the object base class
 
-
+__END__
 
 =pod
 
@@ -152,7 +152,7 @@ Moose::Util::MetaRole - Apply roles to any metaclass, as well as the object base
 
 =head1 VERSION
 
-version 2.0200
+version 2.1005
 
 =head1 SYNOPSIS
 
@@ -283,6 +283,8 @@ It accepts the following keys:
 
 =item application_role_summation
 
+=item applied_attribute
+
 =back
 
 =back
@@ -297,17 +299,13 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
-Stevan Little <stevan@iinteractive.com>
+Moose is maintained by the Moose Cabal, along with the help of many contributors. See L<Moose/CABAL> and L<Moose/CONTRIBUTORS> for details.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
