@@ -3,7 +3,7 @@ BEGIN {
   $Test::Moose::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Test::Moose::VERSION = '2.0401';
+  $Test::Moose::VERSION = '2.1005';
 }
 
 use strict;
@@ -77,18 +77,24 @@ sub has_attribute_ok ($$;$) {
 sub with_immutable (&@) {
     my $block = shift;
     my $before = $Test->current_test;
-    $block->();
+    my $passing_before = (Test::Builder->VERSION < 1.005 ? 0 : $Test->history->pass_count) || 0;
+
+    $block->(0);
     Class::MOP::class_of($_)->make_immutable for @_;
-    $block->();
+    $block->(1);
+
     my $num_tests = $Test->current_test - $before;
-    return all { $_ } ($Test->summary)[-$num_tests..-1];
+    my $all_passed = Test::Builder->VERSION < 1.005
+        ? all { $_ } ($Test->summary)[-$num_tests..-1]
+        : $num_tests == $Test->history->pass_count - $passing_before;
+    return $all_passed;
 }
 
 1;
 
 # ABSTRACT: Test functions for Moose specific features
 
-
+__END__
 
 =pod
 
@@ -98,7 +104,7 @@ Test::Moose - Test functions for Moose specific features
 
 =head1 VERSION
 
-version 2.0401
+version 2.1005
 
 =head1 SYNOPSIS
 
@@ -137,6 +143,9 @@ does for the methods.
 Runs B<CODE> (which should contain normal tests) twice, and make each
 class in C<@class_names> immutable in between the two runs.
 
+The B<CODE> block is called with a single boolean argument indicating whether
+or not the classes have been made immutable yet.
+
 =back
 
 =head1 TODO
@@ -179,14 +188,9 @@ Moose is maintained by the Moose Cabal, along with the help of many contributors
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2013 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
